@@ -1,13 +1,18 @@
 import os
 #import jgtdotenv
 from dotenv import load_dotenv
+from dotenv import dotenv_values
 
 load_dotenv()  # take environment variables from .env.
+#env=load_dotenv(os.getenv(os.getcwd()))
+env = dotenv_values(".env")
 if os.getenv('FXCM_TOKEN_REST_API_DEMO') == "":
   load_dotenv(os.getenv('HOME'))
 if os.getenv('FXCM_TOKEN_REST_API_DEMO') == "":
   load_dotenv(os.getenv(os.getcwd()))
 #@title TOKENS
+def getenv(tvar):
+  return os.getenv(tvar)
 
 # keep expiring...
 FXCM_TOKEN_REST_API_DEMO = os.getenv('FXCM_TOKEN_REST_API_DEMO')
